package com.ruoyi.project.intact.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.project.intact.domain.TIntactGj;
import com.ruoyi.project.intact.domain.TIntactYsj;

/**
 * 设备完整性压缩机台账Service接口
 * 
 * @author ruoyi
 * @date 2022-06-21
 */
public interface ITIntactYsjService  extends IService<TIntactYsj>
{
    /**
     * 查询设备完整性压缩机台账
     * 
     * @param id 设备完整性压缩机台账ID
     * @return 设备完整性压缩机台账
     */
    public TIntactYsj selectTIntactYsjById(Long id);

    /**
     * 查询设备完整性压缩机台账列表
     * 
     * @param tIntactYsj 设备完整性压缩机台账
     * @return 设备完整性压缩机台账集合
     */
    public List<TIntactYsj> selectTIntactYsjList(TIntactYsj tIntactYsj);

    /**
     * 新增设备完整性压缩机台账
     * 
     * @param tIntactYsj 设备完整性压缩机台账
     * @return 结果
     */
    public int insertTIntactYsj(TIntactYsj tIntactYsj);

    /**
     * 修改设备完整性压缩机台账
     * 
     * @param tIntactYsj 设备完整性压缩机台账
     * @return 结果
     */
    public int updateTIntactYsj(TIntactYsj tIntactYsj);

    /**
     * 批量删除设备完整性压缩机台账
     * 
     * @param ids 需要删除的设备完整性压缩机台账ID
     * @return 结果
     */
    public int deleteTIntactYsjByIds(Long[] ids);

    /**
     * 删除设备完整性压缩机台账信息
     * 
     * @param id 设备完整性压缩机台账ID
     * @return 结果
     */
    public int deleteTIntactYsjById(Long id);
}
