package com.ruoyi.project.intact.controller;

import java.util.Date;
import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.intact.domain.TIntactYsj;
import com.ruoyi.project.intact.service.ITIntactYsjService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 设备完整性压缩机台账Controller
 *
 * @author ruoyi
 * @date 2022-06-21
 */
@RestController
@RequestMapping("/intact/ysj")
public class TIntactYsjController extends BaseController
{
    @Autowired
    private ITIntactYsjService tIntactYsjService;

    /**
     * 查询设备完整性压缩机台账列表
     */
    @PreAuthorize("@ss.hasPermi('intact:ysj:list')")
    @GetMapping("/list")
    public TableDataInfo list(TIntactYsj tIntactYsj)
    {
        startPage();
        List<TIntactYsj> list = tIntactYsjService.selectTIntactYsjList(tIntactYsj);
        return getDataTable(list);
    }

    /**
     * 导出设备完整性压缩机台账列表
     */
    @PreAuthorize("@ss.hasPermi('intact:ysj:export')")
    @Log(title = "设备完整性压缩机台账", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TIntactYsj tIntactYsj)
    {
        List<TIntactYsj> list = tIntactYsjService.selectTIntactYsjList(tIntactYsj);
        ExcelUtil<TIntactYsj> util = new ExcelUtil<TIntactYsj>(TIntactYsj.class);
        return util.exportExcel(list, "ysj");
    }

    /**
     * 获取设备完整性压缩机台账详细信息
     */
    @PreAuthorize("@ss.hasPermi('intact:ysj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tIntactYsjService.selectTIntactYsjById(id));
    }

    /**
     * 新增设备完整性压缩机台账
     */
    @PreAuthorize("@ss.hasPermi('intact:ysj:add')")
    @Log(title = "设备完整性压缩机台账", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TIntactYsj tIntactYsj)
    {
        //获取操作人员ID
        Long userId = getUserId();
        tIntactYsj.setCreaterCode(userId.toString());
        tIntactYsj.setCreatedate(new Date());
        return toAjax(tIntactYsjService.insertTIntactYsj(tIntactYsj));
    }

    /**
     * 修改设备完整性压缩机台账
     */
    @PreAuthorize("@ss.hasPermi('intact:ysj:edit')")
    @Log(title = "设备完整性压缩机台账", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TIntactYsj tIntactYsj)
    {
        return toAjax(tIntactYsjService.updateTIntactYsj(tIntactYsj));
    }

    /**
     * 删除设备完整性压缩机台账
     */
    @PreAuthorize("@ss.hasPermi('intact:ysj:remove')")
    @Log(title = "设备完整性压缩机台账", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tIntactYsjService.deleteTIntactYsjByIds(ids));
    }
}
